@@ -12,7 +12,7 @@ use Google::Voice::Call;
 
 use Mojo::Base -base;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 __PACKAGE__->attr([qw/ ua rnr_se /]);
 
@@ -29,6 +29,8 @@ sub login {
     my ($user, $pass) = @_;
     my $c = $self->ua;
 
+    $c->max_redirects(6);    # Google seems to like redirects everywhere
+
     # GALX value
     my $el =
       $c->get('https://accounts.google.com/ServiceLogin')
@@ -45,7 +47,6 @@ sub login {
     );
 
     # rnr_se required for subsequent requests
-    $c->max_redirects(4);    # 3-4 redirects before rnr_se is available
     $el =
       $c->get('https://www.google.com/voice#inbox')
       ->res->dom->at('input[name="_rnr_se"]');
@@ -250,4 +251,6 @@ Glen Hinkle tempire@cpan.org
 
 David Jones
 
+Graham Forest
+
 =cut
